package sftest

// ------------------------ 检测商户是否存在 -------------------------
// 请求参数
type CheckMchExistReq struct {
	ApiUrl        string `json:"-"` // 接口地址
	RequestNumber string `json:"request_number"` // 非必传 请求流水号
	Timestamp     int64 `json:"timestamp"` // 必传 时间戳
	ChannelCode   string `json:"channel_code"` // 必传 渠道编号 固定值：SUNMI
	CompanyName   string `json:"company_name"` // 必传 店铺名称
	Account       string `json:"account"` // 必传 账户
}
// 设置接口地址
func (c CheckMchExistReq) APIName() string {
	return c.ApiUrl
}
// 响应参数
type CheckMchExistRsp struct {
	Code       int64   `json:"code"`
	Message    string `json:"message"`
	Timestamp  int64   `json:"timestamp"`// 调用本接口提交的时间戳
	Status     int64 `json:"status"`// 有效期，单位：秒
	MchId      string `json:"mch_id"`// 如果status为1，必须要传入此值
	StoreId    string `json:"store_id"`// 如果status为1必须传入此值
	Trial      int64 `json:"trial"`// 0：不在试用中 1：在试用中
	AuthList   AuthList `json:"auth_list"`// 0：不在试用中 1：在试用中
	AppList    []string `json:"app_list"`// 返回当前店铺状 态下可订购的软 件 SKU 编码
}

func (c *CheckMchExistRsp) IsSuccess() bool {
	return c.Code == 0
}

// ------------------------ 创建店铺 -------------------------
// 请求参数
type CreateMchReq struct {
	ApiUrl        string `json:"-"` // 必传 接口地址
	RequestNumber string `json:"request_number"` // 非必传 请求流水号
	Timestamp     int64 `json:"timestamp"` // 必传 时间戳
	ChannelCode   string `json:"channel_code"` // 必传 渠道编号 固定值：SUNMI
	CompanyName   string `json:"company_name"` // 必传 店铺名称
	StoreName     string `json:"store_name"` // 必传 创建商户时默认开一 个门店
	TradeTypeId   int64 `json:"trade_type_id"` // 必传 默认门店行业类别 ID，
	TradeTypeName string `json:"trade_type_name"` // 必传 默认门店行业类别名称
	Province      string `json:"province"` // 非必传 省
	City          string `json:"city"` // 非必传 市
	Region        string `json:"region"` // 非必传 区
	Address       string `json:"address"` // 必传 商户/默认门店地址
	Contactor     string `json:"contactor"` // 必传 商家联系人姓名
	Account       string `json:"account"` // 必传 用户登录的账号
	Mobile        string `json:"mobile"` // 必传 联系人手机号码
	Password      string `json:"password"` // 必传 8 位数字字母组合
	Email         string `json:"email"` // 非必传 联系电子邮箱
	Remark        string `json:"remark"` // 非必传 联系电子邮箱
	PaymentMode   int64 `json:"payment_mode"` // 非必传 门店业态
	Telephone     string `json:"telephone"` // 非必传 门店座机电话
}
// 设置接口地址
func (c CreateMchReq) APIName() string {
	return c.ApiUrl
}
// 响应参数
type CreateMchRsp struct {
	Code          int64   `json:"code"`
	Message       string `json:"message"`
	Timestamp     int64   `json:"timestamp"`// 调用本接口提交的时间戳
	Status        int64 `json:"status"`// 有效期，单位：秒
	MchId         string `json:"mch_id"`// 商户 ID
	CompanyName   string `json:"company_name"`// 商户名称
	StoreId       string `json:"store_id"`// 默认门店 ID
	StoreName     string `json:"store_name"`// 默认门店名称
	LoginUsername string `json:"login_username"`// 0：登录用户名
	LoginPassword string `json:"Login_password"`// 登录用户名
	LoginOther    string `json:"login_other"`// 其他登录信息
}

func (c *CreateMchRsp) IsSuccess() bool {
	return c.Code == 0
}

// ------------------------ 订购软件许可 -------------------------
// 请求参数
type OrderAuthReq struct {
	ApiUrl        string `json:"-"` // 必传 接口地址
	RequestNumber string `json:"request_number"` // 非必传 请求流水号
	Timestamp     int64 `json:"timestamp"` // 必传 时间戳
	ChannelCode   string `json:"channel_code"` // 必传 渠道编号 固定值：SUNMI
	MchId         string `json:"mch_id"` // 必传 商户 ID
	StoreId       string `json:"store_id"`// 必传 店铺 ID
	TradeType     int64 `json:"trade_type"` // 必传 交易类型 1:新购/试用 2:续费 3:升级 4:增值服务
	AppCode       string `json:"app_code"` // 必传 软件规格码
	AppNum        int64 `json:"app_num"` // 必传 应用数量
}
// 设置接口地址
func (c OrderAuthReq) APIName() string {
	return c.ApiUrl
}
// 响应参数
type OrderAuthRsp struct {
	Code          int64   `json:"code"`
	Message       string `json:"message"`
	Timestamp     int64   `json:"timestamp"`// 调用本接口提交的时间戳
	MchId         string `json:"mch_id"`// 商户 ID
	AuthList      AuthList `json:"auth_list"`// 应用授权列表
}

type AuthList struct {
	AppCode       string `json:"app_code"` //软件规格码
	AuthId        string `json:"auth_id"`  //授权 ID
	AuthStart     string `json:"auth_start"` //授权开始日期
	AuthEnd       string `json:"auth_end"` //授权结束日期
}

func (c *OrderAuthRsp) IsSuccess() bool {
	return c.Code == 0
}