package sftest

import (
	"encoding/json"
	"github.com/spf13/cast"
	"github.com/sunmi-OS/gocore/utils"
	"io/ioutil"
	"net/http"
	"net/url"
	"sort"
	"strings"
)

type Param interface {
	// 用于提供访问的 method
	APIName() string
}

type Client struct {
	Key string
}

func New(key string) (client *Client) {
	client = &Client{Key:key}
	return client
}

func (c *Client) urlValues(param Param) (value url.Values, err error)  {
	var paramMap = make(map[string]interface{})
	j, err := json.Marshal(param)
	if err != nil {
		return
	}
	err = json.Unmarshal(j, &paramMap)
	if err != nil {
		return
	}
	var keys []string
	var p = url.Values{}
	for k, v := range paramMap {
		vStr := cast.ToString(v)
		if vStr != "" {
			p.Add(k, vStr)
			keys = append(keys, k)
		}
	}
	sort.Strings(keys)
	signStr := ""
	for _, key := range keys{
		signStr += "&" + key + "=" + p.Get(key)
	}
	signStr = signStr[1:]
	signStr += "&key=" + c.Key
	sign := strings.ToUpper(utils.GetMD5(signStr))
	p.Add("sign", sign)
	return p, nil
}

func (c *Client) doRequest(method string, param Param, result interface{}) (err error) {
	dataUrlVal, err := c.urlValues(param)
	if err != nil {
		return err
	}
	request, err := http.NewRequest(method, param.APIName(), strings.NewReader(dataUrlVal.Encode()))
	if err != nil {
		return
	}
	request.Header.Add("Content-Type","application/x-www-form-urlencoded")
	client := http.Client{}
	resp, err := client.Do(request)
	if err != nil {
		return err
	}
	defer resp.Body.Close()
	respBytes, err := ioutil.ReadAll(resp.Body)
	if err != nil {
		return err
	}
	err = json.Unmarshal(respBytes, result)
	if err != nil {
		return err
	}
	return err
}